[SCM] exiv2 packaging branch, master, updated. debian/0.25-3.1-3734-gdcbc29a

Maximiliano Curia maxy at moszumanska.debian.org
Thu Jul 13 17:41:32 UTC 2017


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/exiv2.git;a=commitdiff;h=b1cde71

The following commit has been merged in the master branch:
commit b1cde710ccddb94d81357bd90aebaf7840cfe9b6
Author: HumanDynamo <caulier.gilles at gmail.com>
Date:   Fri Apr 23 13:58:33 2010 +0000

    branching Sony A100 makenotes
---
 src/makernote_int.hpp |  2 +-
 src/tags.cpp          |  3 +--
 src/tiffcomposite.cpp |  4 ++--
 src/tiffimage.cpp     | 19 ++++++++++++-------
 src/types.hpp         |  1 -
 5 files changed, 16 insertions(+), 13 deletions(-)

diff --git a/src/makernote_int.hpp b/src/makernote_int.hpp
index a2f2625..f333e09 100644
--- a/src/makernote_int.hpp
+++ b/src/makernote_int.hpp
@@ -114,7 +114,7 @@ namespace Exiv2 {
         const uint16_t sony1cs2  = 332; //!< Sony Camera Settings 2 (in Sony1 makernote)
         const uint16_t sony1mcso = 333; //!< Minolta (old) Camera Settings (in Sony1 makernote)
         const uint16_t sony1mcsn = 334; //!< Minolta (new) Camera Settings (in Sony1 makernote)
-        const uint16_t sony1mcs5 = 335; //!< Minolta D5 Camera Settings (in Sony1 makernote)
+        const uint16_t sony1mcsa100=335;//!< Sony A100 Camera Settings (in Sony1 makernote)
         const uint16_t sony1mcs7 = 336; //!< Minolta D7 Camera Settings (in Sony1 makernote)
         const uint16_t sony2cs   = 337; //!< Sony Camera Settings (in Sony2 makernote)
         const uint16_t sony2cs2  = 338; //!< Sony Camera Settings 2 (in Sony2 makernote)
diff --git a/src/tags.cpp b/src/tags.cpp
index 2db6d97..6455821 100644
--- a/src/tags.cpp
+++ b/src/tags.cpp
@@ -175,11 +175,10 @@ namespace Exiv2 {
         { sonyMltIfdId,      "Makernote", "SonyMinolta",  MinoltaMakerNote::tagList      },
         { sony1CsIfdId,      "Makernote", "Sony1Cs",      SonyMakerNote::tagListCs       },
         { sony1Cs2IfdId,     "Makernote", "Sony1Cs2",     SonyMakerNote::tagListCs2      },
-        { sony1MltCs5DIfdId, "Makernote", "Sony1MltCs5D", MinoltaMakerNote::tagListCs5D  },
         { sony1MltCs7DIfdId, "Makernote", "Sony1MltCs7D", MinoltaMakerNote::tagListCs7D  },
         { sony1MltCsOldIfdId,"Makernote", "Sony1MltCsOld",MinoltaMakerNote::tagListCsStd },
         { sony1MltCsNewIfdId,"Makernote", "Sony1MltCsNew",MinoltaMakerNote::tagListCsStd },
-        { sony1MltCsA100IfdId,"Makernote", "Sony1MltCsA100",MinoltaMakerNote::tagListCsA100},
+        { sony1MltCsA100IfdId,"Makernote","Sony1MltCsA100",MinoltaMakerNote::tagListCsA100},
         { sony2CsIfdId,      "Makernote", "Sony2Cs",      SonyMakerNote::tagListCs       },
         { sony2Cs2IfdId,     "Makernote", "Sony2Cs2",     SonyMakerNote::tagListCs2      },
         { lastIfdId,         "(Last IFD info)", "(Last IFD item)", 0 }
diff --git a/src/tiffcomposite.cpp b/src/tiffcomposite.cpp
index 10c5f95..c4df6c8 100644
--- a/src/tiffcomposite.cpp
+++ b/src/tiffcomposite.cpp
@@ -163,10 +163,10 @@ namespace Exiv2 {
         { 332, "Sony1Cs2"     },
         { 333, "Sony1MltCsOld"},
         { 334, "Sony1MltCsNew"},
-        { 335, "Sony1MltCs5D" },
+        { 335, "Sony1MltCsA100" },
         { 336, "Sony1MltCs7D" },
         { 337, "Sony2Cs"      },
-        { 338, "Sony2Cs2"     },
+        { 338, "Sony2Cs2"     }
     };
 
     bool TiffGroupInfo::operator==(const uint16_t& group) const
diff --git a/src/types.hpp b/src/types.hpp
index 1d92155..18652ba 100644
--- a/src/types.hpp
+++ b/src/types.hpp
@@ -230,7 +230,6 @@ namespace Exiv2 {
         sony1Cs2IfdId,
         sony2CsIfdId,
         sony2Cs2IfdId,
-        sony1MltCs5DIfdId,
         sony1MltCs7DIfdId,
         sony1MltCsOldIfdId,
         sony1MltCsNewIfdId,

diff --git a/src/tiffimage.cpp b/src/tiffimage.cpp
index c5067d5..1630f8c 100644
--- a/src/tiffimage.cpp
+++ b/src/tiffimage.cpp
@@ -898,9 +898,9 @@ namespace Exiv2 {
         { 0, ttUnsignedShort, 1 }
     };
 
-    //! Sony Minolta 5D Camera Settings binary array - configuration
-    extern const ArrayCfg sony1MCs5Cfg = {
-        Group::sony1mcs5, // Group for the elements
+    //! Sony Minolta A100 Camera Settings binary array - configuration
+    extern const ArrayCfg sony1MCsA100Cfg = {
+        Group::sony1mcsa100, // Group for the elements
         bigEndian,        // Big endian
         ttUndefined,      // Type for array entry and size element
         notEncrypted,     // Not encrypted
@@ -909,6 +909,12 @@ namespace Exiv2 {
         false,            // Don't concatenate gaps
         { 0, ttUnsignedShort, 1 }
     };
+    //! Sony Minolta A100 Camera Settings binary array - definition
+    extern const ArrayDef sony1MCsA100Def[] = {
+        { 112, ttSignedShort, 1 }, // Exif.Sony1MltCsA100.WhiteBalanceFineTune
+        { 116, ttSignedShort, 1 }, // Exif.Sony1MltCsA100.ColorCompensationFilter
+        { 190, ttSignedShort, 1 }  // Exif.Sony1MltCsA100.ColorCompensationFilter2
+    };
 
     /*
       This table lists for each group in a tree, its parent group and tag.
@@ -999,7 +1005,7 @@ namespace Exiv2 {
         { Tag::root, Group::sony1mcso, Group::sonymltmn, 0x0001    },
         { Tag::root, Group::sony1mcsn, Group::sonymltmn, 0x0003    },
         { Tag::root, Group::sony1mcs7, Group::sonymltmn, 0x0004    },
-        { Tag::root, Group::sony1mcs5, Group::sonymltmn, 0x0114    },
+        { Tag::root, Group::sony1mcsa100, Group::sonymltmn, 0x0114 },
         { Tag::root, Group::sony2mn,   Group::exif,      0x927c    },
         { Tag::root, Group::sony2cs,   Group::sony2mn,   0x0114    },
         { Tag::root, Group::sony2cs2,  Group::sony2mn,   0x0114    },
@@ -1383,8 +1389,7 @@ namespace Exiv2 {
         {    0x0004, Group::sonymltmn, EXV_BINARY_ARRAY(sony1MCs7Cfg, minoCs7Def)}, // minoCs7Def [sic]
         {    0x0088, Group::sonymltmn, newTiffThumbData<0x0089, Group::sonymltmn>},
         {    0x0089, Group::sonymltmn, newTiffThumbSize<0x0088, Group::sonymltmn>},
-        {    0x0114, Group::sonymltmn, EXV_BINARY_ARRAY(sony1MCs5Cfg, minoCs5Def)}, // minoCs5Def [sic]
-//        {    0x0114, Group::sonymltmn, EXV_BINARY_ARRAY(sony1MCs5Cfg, minoCs5Def)}, // A100 CS
+        {    0x0114, Group::sonymltmn, EXV_BINARY_ARRAY(sony1MCsA100Cfg, sony1MCsA100Def)},
         { Tag::next, Group::sonymltmn, newTiffDirectory<Group::ignr>             },
         {  Tag::all, Group::sonymltmn, newTiffEntry                              },
 
@@ -1392,7 +1397,7 @@ namespace Exiv2 {
         {  Tag::all, Group::sony1mcso, newTiffBinaryElement                      },
         {  Tag::all, Group::sony1mcsn, newTiffBinaryElement                      },
         {  Tag::all, Group::sony1mcs7, newTiffBinaryElement                      },
-        {  Tag::all, Group::sony1mcs5, newTiffBinaryElement                      },
+        {  Tag::all, Group::sony1mcsa100,newTiffBinaryElement                    },
 
         // Minolta makernote
         {    0x0001, Group::minoltamn, EXV_SIMPLE_BINARY_ARRAY(minoCsoCfg)       },
-- 
exiv2 packaging



More information about the pkg-kde-commits mailing list